============================
PowerDNS Command Line Client
============================

.. important::

  2015/01/01: The `pdns` project has been deprecated and replaced by
  the `dnssync <https://pypi.python.org/pypi/dnssync>`_ project.
  Please use that instead.
